OC.L10N.register(
    "groupfolders",
    {
    "Deny" : "Diùlt",
    "Allow" : "Ceadaich",
    "Create" : "Cruthaich",
    "Delete" : "Sguab às",
    "Share" : "Co-roinn",
    "Default" : "Bunaiteach",
    "Folder name" : "Ainm a’ phasgain",
    "User" : "Cleachdaiche",
    "Unknown" : "Chan eil fhios",
    "None" : "Chan eil gin",
    "{size} used" : "Tha {size} ’ga chleachdadh",
    "Unset" : "Neo-shuidhich"
},
"nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;");
